Géosuna DOI
===========

[![CI/CD](https://gitlab.univ-nantes.fr/osuna/src/geosuna-doi/badges/main/pipeline.svg)][ci-cd]
[![PyPI](https://img.shields.io/badge/PyPI-geosuna-blue?logo=Python&logoColor=white)][pypi]
[![Lastest release](https://gitlab.univ-nantes.fr/osuna/src/geosuna-doi/-/badges/release.svg)][release]
[![License](https://img.shields.io/pypi/l/geosuna.svg)][license]

[ci-cd]: https://gitlab.univ-nantes.fr/osuna/src/geosuna-doi/pipelines/main/latest
[pypi]: https://pypi.org/project/geosuna
[release]: https://gitlab.univ-nantes.fr/osuna/src/geosuna-doi/-/releases
[license]: https://gitlab.univ-nantes.fr/osuna/src/geosuna-doi/-/blob/main/LICENSE.md

Python library to validate [Géosuna](https://ids.osuna.univ-nantes.fr/) resources to register DOI in [DataCite](https://datacite.org/).


## Install this package
This package is [available on PyPI](https://pypi.org/project/geosuna/) and can be installed with `pip`:
```bash
pip install geosuna
```

## Validate a ressource
```bash
geosuna-validate 2ae0bfa2-d8fa-42ab-bc16-4724a3b36a29 626c9459-1cd8-43a2-a371-6856e442a4aa
```

## Create a new DOI
```bash
geosuna-doi 626c9459-1cd8-43a2-a371-6856e442a4aa
```

## Create DOI badges
```bash
geosuna-doi --badges 626c9459-1cd8-43a2-a371-6856e442a4aa
```

## Developer

This package is managed with [uv](https://docs.astral.sh/uv/).

Check the syntax:
```bash
uv run ruff format
uv run ruff check
```

Run the tests:
```bash
uv run pytest
```
